bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.plot
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.plot